@@ -1,7 +1,3 @@
-#ifndef YYERRCODE
-#define YYERRCODE 256
-#endif
-
 #define CLASS 1
 #define RESOURCE 2
 #define DATATYPE 3
